@@ -20,15 +20,16 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from dataiter.array import Array # noqa
+from dataiter.vector import Vector # noqa
 from dataiter.data_frame import DataFrame # noqa
 from dataiter.data_frame import DataFrameColumn # noqa
 from dataiter.list_of_dicts import ListOfDicts # noqa
 from dataiter.list_of_dicts import ObsoleteError # noqa
 from dataiter.list_of_dicts import ObsoleteListOfDicts # noqa
 
-__version__ = "0.8"
+__version__ = "0.9"
 
+DEFAULT_PEEK_ELEMENTS = 10
 DEFAULT_PEEK_ITEMS = 3
 DEFAULT_PEEK_ROWS = 10
 PRINT_FLOAT_PRECISION = 6
